summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmparser.h')
-rw-r--r--kpovmodeler/pmparser.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpovmodeler/pmparser.h b/kpovmodeler/pmparser.h
index 3c48bb49..07a28ab6 100644
--- a/kpovmodeler/pmparser.h
+++ b/kpovmodeler/pmparser.h
@@ -81,13 +81,13 @@ public:
*
* Appends all parsed objects to the list.
*
* tqparent is the object where the parsed objects will be inserted as
* tqchildren behind the object after. These parameters are used to check
* the consistency of declares and links.
*
* Set tqparent and after to 0 if and only if a document is parsed/opened.
*/
- void parse( PMObjectList* list, PMObject* tqparent,
+ void parse( PMObjectList* list, PMObject* parent,
PMObject* after );
/**
@@ -196,12 +196,12 @@ public:
*/
PMSymbol* getSymbol( const TQString& id ) const;
/**
* Tries to insert obj as child of tqparent. If tqparent is 0, the object
* will be inserted in the list of top level objects.
*
* Returns true if the object could be inserted.
*/
- bool insertChild( PMObject* obj, PMObject* tqparent );
+ bool insertChild( PMObject* obj, PMObject* parent );
protected:
/**
@@ -217,7 +217,7 @@ protected:
*/
PMPart* m_pPart;
/**
* tqparent object where the parsed top level objects
* will be inserted _later_ (not from the parser) as tqchildren
*/
const PMObject* m_pTopParent;
@@ -81,13 +81,13 @@ public:
* Appends all parsed objects to the list.
*
- * tqparent is the object where the parsed objects will be inserted as
+ * parent is the object where the parsed objects will be inserted as
* tqchildren behind the object after. These parameters are used to check
* the consistency of declares and links.
@@ -81,13 +81,13 @@ public:
* the consistency of declares and links.
*
- * Set tqparent and after to 0 if and only if a document is parsed/opened.
+ * Set parent and after to 0 if and only if a document is parsed/opened.
*/
@@ -196,12 +196,12 @@ public:
PMSymbol* getSymbol( const TQString& id ) const;
/**
- * Tries to insert obj as child of tqparent. If tqparent is 0, the object
+ * Tries to insert obj as child of parent. If parent is 0, the object
* will be inserted in the list of top level objects.
*
@@ -217,7 +217,7 @@ protected:
PMPart* m_pPart;
/**
- * tqparent object where the parsed top level objects
+ * parent object where the parsed top level objects
* will be inserted _later_ (not from the parser) as tqchildren
*/